@@ -148,6 +148,13 @@ model2layers = {
     "zhiheng-huang/bert-base-uncased-embedding-relative-key": 4,  # 0.5995636595368777
     "zhiheng-huang/bert-base-uncased-embedding-relative-key-query": 7,  # 0.6303599452145718
     "zhiheng-huang/bert-large-uncased-whole-word-masking-embedding-relative-key-query": 19,  # 0.6896878492850327
+    'google/mt5-small': 8, # 0.6401166527273479
+    'google/mt5-base': 11, # 0.5663956536597241
+    'google/mt5-large': 19, # 0.6430931371732798
+    'google/mt5-xl': 24, # 0.6707200963021145
+    'google/bigbird-roberta-base': 10, # 0.6695606423502717
+    'google/bigbird-roberta-large': 14, # 0.6755874042374509
+    'google/bigbird-base-trivia-itc': 8, # 0.6930725491629892
 }
 
 
@@ -219,6 +226,11 @@ def get_model(model_type, num_layers, all_layers=None):
                     0 <= num_layers <= model.encoder.config.num_hidden_layers
                 ), f"Invalid num_layers: num_layers should be between 0 and {model.encoder.config.num_hidden_layers} for {model_type}"
                 model.encoder.config.num_hidden_layers = num_layers
+            elif hasattr(model.encoder, "block"):  # t5
+                assert (
+                    0 <= num_layers <= len(model.encoder.block)
+                ), f"Invalid num_layers: num_layers should be between 0 and {len(model.encoder.block)} for {model_type}"
+                model.encoder.block = torch.nn.ModuleList([layer for layer in model.encoder.block[:num_layers]])
             else:  # bert, roberta
                 assert (
                     0 <= num_layers <= len(model.encoder.layer)
@@ -229,6 +241,11 @@ def get_model(model_type, num_layers, all_layers=None):
                 0 <= num_layers <= len(model.transformer.layer)
             ), f"Invalid num_layers: num_layers should be between 0 and {len(model.transformer.layer)} for {model_type}"
             model.transformer.layer = torch.nn.ModuleList([layer for layer in model.transformer.layer[:num_layers]])
+        elif hasattr(model, "layers"):  # bart
+            assert (
+                0 <= num_layers <= len(model.layers)
+            ), f"Invalid num_layers: num_layers should be between 0 and {len(model.layers)} for {model_type}"
+            model.layers = torch.nn.ModuleList([layer for layer in model.layers[:num_layers]])
         else:
             raise ValueError("Not supported")
     else:
